@@ -370,11 +370,8 @@ class StartupWizardGuiPitivi(FullGuiPitivi):
 
     def __init__(self, debug=False):
         FullGuiPitivi.__init__(self, debug)
-        self.projectManager.newBlankProject()
 
     def _createGui(self):
-        self.projectManager.connect("new-project-loading", self._hideWizardCb)
-        self.projectManager.connect("new-project-failed", self._showWizardCb)
         self.wizard = StartUpWizard(self)
         return FullGuiPitivi._createGui(self)
 
@@ -382,13 +379,6 @@ class StartupWizardGuiPitivi(FullGuiPitivi):
         FullGuiPitivi._showGui(self)
         self.wizard.show()
 
-    def _hideWizardCb(self, unused_projectManager, uri):
-        if uri is not None:
-            self.wizard.hide()
-
-    def _showWizardCb(self, unused_projectManager, unused_uri, unused_exception):
-        self.wizard.show()
-
 
 class PreviewGuiPitivi(GuiPitivi):
     """
@@ -398,7 +388,6 @@ class PreviewGuiPitivi(GuiPitivi):
 
     def __init__(self, project_filename, debug=False):
         GuiPitivi.__init__(self, debug)
-
         self._loadProject(project_filename)
 
     def _createGui(self):
@@ -475,13 +464,13 @@ def _parse_options(argv):
 
     # Validate options.
     if options.render_output and options.preview:
-        parser.error("-p and -r cannot be used simultaneously")
+        parser.error(_("-p and -r cannot be used simultaneously"))
 
     if options.import_sources and (options.render_output or options.preview):
-        parser.error("-r or -p and -i are incompatible")
+        parser.error(_("-r or -p and -i are incompatible"))
 
     if options.add_to_timeline and not options.import_sources:
-        parser.error("-a requires -i")
+        parser.error(_("-a requires -i"))
 
     # Validate args.
     if options.import_sources:
@@ -489,13 +478,13 @@ def _parse_options(argv):
         pass
     elif options.render_output:
         if len(args) != 1:
-            parser.error("-r requires exactly one PROJECT_FILE")
+            parser.error(_("-r requires exactly one PROJECT_FILE"))
     elif options.preview:
         if len(args) != 1:
-            parser.error("-p requires exactly one PROJECT_FILE")
+            parser.error(_("-p requires exactly one PROJECT_FILE"))
     else:
         if len(args) > 1:
-            parser.error("Cannot open more than one PROJECT_FILE")
+            parser.error(_("Cannot open more than one PROJECT_FILE"))
 
     return options, args
 
