@@ -25,17 +25,6 @@ Enables identical use for installed and uninstalled versions.
 
 import os.path
 
-LIBDIR = '/usr/local/lib'
-PKGDATADIR = '/usr/local/share/pitivi'
-pitivi_version = '0.14.1'
-APPNAME = 'PiTiVi'
-APPURL = 'http://www.pitivi.org/'
-APPMANUALURL = 'http://www.pitivi.org/?go=documentation'
-PYGTK_REQ = '2.17.0'
-PYGST_REQ = '0.10.19'
-GST_REQ = '0.10.28'
-GNONLIN_REQ = '0.10.16'
-PYCAIRO_REQ = '1.0.0'
 
 def _get_root_dir():
     return '/'.join(os.path.dirname(os.path.abspath(__file__)).split('/')[:-1])
@@ -44,6 +33,26 @@ def _in_devel():
     rd = _get_root_dir()
     return os.path.exists(os.path.join(rd, '.git'))
 
+
+LIBDIR = '/usr/local/lib'
+PKGDATADIR = '/usr/local/share/pitivi'
+pitivi_version = '0.14.2'
+APPNAME = 'PiTiVi'
+APPURL = 'http://www.pitivi.org/'
+PYGTK_REQ = '2.24.0'
+PYGST_REQ = '0.10.19'
+GST_REQ = '0.10.28'
+GNONLIN_REQ = '0.10.16'
+PYCAIRO_REQ = '1.0.0'
+
+if _in_devel():
+    APPMANUALURL_OFFLINE = 'ghelp://%s' % os.path.join(_get_root_dir(), 'help/C')
+else:
+    APPMANUALURL_OFFLINE = 'ghelp:pitivi'
+
+APPMANUALURL_ONLINE = 'http://www.pitivi.org/manual'
+
+
 def get_data_dir():
     if _in_devel():
         datadir = os.path.join(_get_root_dir(), "data")
