@@ -20,6 +20,7 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 # Boston, MA 02110-1301, USA.
 
+import collections
 from bisect import bisect_left
 
 from pitivi.signalinterface import Signallable
@@ -32,6 +33,7 @@ from pitivi.utils import start_insort_right, infinity, getPreviousObject, \
         getNextObject
 from pitivi.timeline.gap import Gap, SmallestGapsFinder, invalid_gap
 from pitivi.stream import VideoStream
+from pitivi.timeline.align import AutoAligner
 
 # Selection modes
 SELECT = 0
@@ -1633,14 +1635,37 @@ class Timeline(Signallable, Loggable):
                 track = track_object.track
                 track.removeTrackObject(track_object)
 
+    def removeMultipleTimelineObjects(self, objs, deep=False):
+        """
+        Remove multiple objects from the Timeline.
+
+        @param objs: The collection of objects to remove
+        @type obj: collection(L{TimelineObject})
+        @param deep: If C{True}, remove the L{TrackObject}s associated with
+             these objects.
+        @type deep: C{bool}
+        @raises TimelineError: If the object doesn't belong to the timeline.
+        """
+        for obj in objs:
+            self.removeTimelineObject(obj, False)
+
+        # If we are going to remove the associated track objects, first
+        # group them by track so we can use the track's removeMultiple method.
+        if deep:
+            track_aggregate = collections.defaultdict(list)
+            for obj in objs:
+                for track_object in obj.track_objects:
+                    track_aggregate[track_object.track].append(track_object)
+            for track, objects_to_remove in track_aggregate.items():
+                track.removeMultipleTrackObjects(objects_to_remove)
+
     def removeFactory(self, factory):
         """Remove every instance factory in the timeline
         @param factory: the factory to remove from the timeline
         """
         objs = [obj for obj in self.timeline_objects if obj.factory is
             factory]
-        for obj in objs:
-            self.removeTimelineObject(obj, deep=True)
+        self.removeMultipleTimelineObjects(objs, deep=True)
 
     def usesFactory(self, factory):
         """
@@ -1958,13 +1983,27 @@ class Timeline(Signallable, Loggable):
 
         self.selection.setSelection(new_track_objects, SELECT_ADD)
 
+    def alignSelection(self, callback):
+        """
+        Auto-align the selected set of L{TimelineObject}s based on their
+        contents.  Return asynchronously, and call back when finished.
+
+        @param callback: function to call (with no arguments) when finished.
+        @type callback: function
+        @returns: a L{ProgressMeter} indicating the state of the alignment
+            process
+        @rtype: L{ProgressMeter}
+        """
+        auto_aligner = AutoAligner(self.selection.selected, callback)
+        progress_meter = auto_aligner.start()
+        return progress_meter
+
     def deleteSelection(self):
         """
         Removes all the currently selected L{TimelineObject}s from the Timeline.
         """
         self.unlinkSelection()
-        for timeline_object in self.selection:
-            self.removeTimelineObject(timeline_object, deep=True)
+        self.removeMultipleTimelineObjects(self.selection, deep=True)
         self.selection.setSelection(set([]), SELECT)
 
     def split(self, time):
