@@ -25,6 +25,8 @@ Class handling the midle pane
 import gtk
 import pango
 import dnd
+import gst
+import os
 
 from gettext import gettext as _
 
@@ -34,8 +36,11 @@ from pitivi.stream import VideoStream
 
 from pitivi.ui.gstwidget import GstElementSettingsWidget
 from pitivi.ui.effectsconfiguration import EffectsPropertiesHandling
+from pitivi.ui.depsmanager import DepsManager
 from pitivi.ui.common import PADDING, SPACING
-from pitivi.ui import dynamic
+from pitivi.configure import get_ui_dir
+from pitivi.check import soft_deps
+from pitivi.ui.effectlist import HIDDEN_EFFECTS
 
 (COL_ACTIVATED,
  COL_TYPE,
@@ -49,36 +54,59 @@ class ClipPropertiesError(Exception):
     pass
 
 
-class ClipProperties(gtk.VBox, Loggable):
+class ClipProperties(gtk.ScrolledWindow, Loggable):
     """
     Widget for configuring clips properties
     """
 
     def __init__(self, instance, uiman):
-        gtk.VBox.__init__(self)
+        gtk.ScrolledWindow.__init__(self)
         Loggable.__init__(self)
 
+        self.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
+        self.set_shadow_type(gtk.SHADOW_NONE)
+
+        vp = gtk.Viewport()
+        vp.set_shadow_type(gtk.SHADOW_NONE)
+        self.add(vp)
+
         self.app = instance
         self.settings = instance.settings
         self._project = None
+        self.transformation_expander = None
         self.info_bar_box = gtk.VBox()
 
+        vbox = gtk.VBox()
+        vp.add(vbox)
+
         self.effect_properties_handling = EffectsPropertiesHandling(instance.action_log)
+
         self.effect_expander = EffectProperties(instance,
                                                 self.effect_properties_handling,
                                                 self)
 
-        self.pack_start(self.info_bar_box, expand=False, fill=True)
-        self.pack_end(self.effect_expander, expand=True, fill=True)
+        vbox.pack_start(self.info_bar_box, expand=False, fill=True)
+
+        self.transformation_expander = TransformationProperties(
+            instance, instance.action_log)
+        vbox.pack_start(self.transformation_expander, expand=False, fill=False)
+        self.transformation_expander.show()
+
+        vbox.pack_end(self.effect_expander, expand=True, fill=True)
+        vbox.set_spacing(SPACING)
 
         self.info_bar_box.show()
         self.effect_expander.show()
+        vbox.show()
+        vp.show()
         self.show()
 
     def _setProject(self, project):
         self._project = project
         if project:
             self.effect_expander._connectTimelineSelection(self._project.timeline)
+            if self.transformation_expander:
+                self.transformation_expander.timeline = self._project.timeline
 
     def _getProject(self):
         return self._project
@@ -101,7 +129,7 @@ class ClipProperties(gtk.VBox, Loggable):
         return label, info_bar
 
 
-class EffectProperties(gtk.HBox):
+class EffectProperties(gtk.Expander, gtk.HBox):
     """
     Widget for viewing and configuring effects
     """
@@ -109,6 +137,7 @@ class EffectProperties(gtk.HBox):
     # to put in ClipProperties, that is why this is done this way
 
     def __init__(self, instance, effect_properties_handling, clip_properties):
+        gtk.Expander.__init__(self)
         gtk.HBox.__init__(self)
         #self.set_expanded(True)
 
@@ -205,13 +234,13 @@ class EffectProperties(gtk.HBox):
         self.app.connect("new-project-loaded",
             self._newProjectLoadedCb)
 
-        #self.connect('notify::expanded', self._expandedCb)
-
         self._table.attach(self.treeview_scrollwin, 0, 1, 2, 3)
 
         self._vcontent.pack1(self._table, resize=True, shrink=False)
         self._showInfoBar()
         self._vcontent.show()
+        self.set_expanded(True)
+        self.set_label("Effects configuration")
 
     def _newProjectLoadedCb(self, app, project):
         self.clip_properties.project = project
@@ -247,6 +276,7 @@ class EffectProperties(gtk.HBox):
                 timeline_object.connect("track-object-removed", self._trackRemovedRemovedCb)
         else:
             self.timeline_objects = []
+            self.set_sensitive(False)
         self._updateAll()
 
     def  _trackObjectAddedCb(self, unused_timeline_object, track_object):
@@ -320,8 +350,8 @@ class EffectProperties(gtk.HBox):
         track_effect.active = not track_effect.active
         self.app.action_log.commit()
 
-    #def _expandedCb(self, expander, params):
-    #    self._updateAll()
+    def _expandedCb(self, expander, params):
+        self._updateAll()
 
     def _treeViewQueryTooltipCb(self, treeview, x, y, keyboard_mode, tooltip):
         context = treeview.get_tooltip_context(x, y, keyboard_mode)
@@ -335,19 +365,19 @@ class EffectProperties(gtk.HBox):
         return True
 
     def _updateAll(self):
-        #if self.get_expanded():
-        self._removeEffectBt.set_sensitive(False)
-        if len(self.timeline_objects) == 1:
-            self._setEffectDragable()
-            self._updateTreeview()
-            self._updateEffectConfigUi()
+        if self.get_expanded():
+            self._removeEffectBt.set_sensitive(False)
+            if len(self.timeline_objects) == 1:
+                self._setEffectDragable()
+                self._updateTreeview()
+                self._updateEffectConfigUi()
+            else:
+                self._hideEffectConfig()
+                self.storemodel.clear()
+                self._showInfoBar()
+            self._vcontent.show()
         else:
-            self._hideEffectConfig()
-            self.storemodel.clear()
-            self._showInfoBar()
-        self._vcontent.show()
-        #else:
-        #    self._vcontent.hide()
+            self._vcontent.hide()
 
     def _activeChangedCb(self, unusedObj, unusedActive):
         self._updateTreeview()
@@ -355,20 +385,21 @@ class EffectProperties(gtk.HBox):
     def _updateTreeview(self):
         self.storemodel.clear()
         for track_effect in self.selected_effects:
-            to_append = [track_effect.gnl_object.get_property("active")]
-            track_effect.gnl_object.connect("notify::active",
-                                            self._activeChangedCb)
-            if isinstance(track_effect.factory.getInputStreams()[0],
-                          VideoStream):
-                to_append.append("Video")
-            else:
-                to_append.append("Audio")
+            if not track_effect.factory.effectname in HIDDEN_EFFECTS:
+                to_append = [track_effect.gnl_object.get_property("active")]
+                track_effect.gnl_object.connect("notify::active",
+                                                self._activeChangedCb)
+                if isinstance(track_effect.factory.getInputStreams()[0],
+                              VideoStream):
+                    to_append.append("Video")
+                else:
+                    to_append.append("Audio")
 
-            to_append.append(track_effect.factory.getHumanName())
-            to_append.append(track_effect.factory.getDescription())
-            to_append.append(track_effect)
+                to_append.append(track_effect.factory.getHumanName())
+                to_append.append(track_effect.factory.getDescription())
+                to_append.append(track_effect)
 
-            self.storemodel.append(to_append)
+                self.storemodel.append(to_append)
 
     def _showInfoBar(self):
         if self._info_bar is None:
@@ -379,11 +410,11 @@ class EffectProperties(gtk.HBox):
         self.txtlabel.show()
         self._info_bar.show()
 
-        self.treeview.set_sensitive(False)
+        self.set_sensitive(False)
         self._table.show_all()
 
     def _setEffectDragable(self):
-        self.treeview.set_sensitive(True)
+        self.set_sensitive(True)
         self._table.show_all()
         self._info_bar.hide_all()
 
@@ -430,3 +461,170 @@ class EffectProperties(gtk.HBox):
         if self._effect_config_ui:
             self._effect_config_ui.hide()
             self._effect_config_ui = None
+
+
+class TransformationProperties(gtk.Expander):
+    """
+    Widget for viewing and configuring speed
+    """
+    __signals__ = {
+        'selection-changed': []}
+
+    def __init__(self, app, action_log):
+        gtk.Expander.__init__(self)
+        self.action_log = action_log
+        self.app = app
+        self._timeline = None
+        self._current_tl_obj = None
+        self.spin_buttons = {}
+        self.default_values = {}
+        self.set_label(_("Transformation configuration"))
+        self.set_sensitive(False)
+
+        if not "Frei0r" in soft_deps:
+            self.builder = gtk.Builder()
+            self.builder.add_from_file(os.path.join(get_ui_dir(),
+                        "cliptransformation.ui"))
+
+            self.add(self.builder.get_object("transform_box"))
+            self.show_all()
+            self._initButtons()
+        self.connect('notify::expanded', self._expandedCb)
+
+    def _initButtons(self):
+        self.zoom_scale = self.builder.get_object("zoom_scale")
+        self.zoom_scale.connect("value-changed", self._zoomViewerCb)
+        clear_button = self.builder.get_object("clear_button")
+        clear_button.connect("clicked", self._defaultValuesCb)
+
+        self._getAndConnectToEffect("xpos_spinbtn", "tilt_x")
+        self._getAndConnectToEffect("ypos_spinbtn", "tilt_y")
+
+        self._getAndConnectToEffect("width_spinbtn", "scale_x")
+        self._getAndConnectToEffect("height_spinbtn", "scale_y")
+
+        self._getAndConnectToEffect("crop_left_spinbtn", "clip_left")
+        self._getAndConnectToEffect("crop_right_spinbtn", "clip_right")
+        self._getAndConnectToEffect("crop_top_spinbtn", "clip_top")
+        self._getAndConnectToEffect("crop_bottom_spinbtn", "clip_bottom")
+        self.connectSpinButtonsToFlush()
+
+    def _zoomViewerCb(self, scale):
+        self.app.gui.viewer.setZoom(scale.get_value())
+
+    def _expandedCb(self, expander, params):
+        if not "Frei0r" in soft_deps:
+            if self._current_tl_obj:
+                self.effect = self._findOrCreateEffect("frei0r-filter-scale0tilt")
+                self._updateSpinButtons()
+                self.set_expanded(self.get_expanded())
+                self._updateBoxVisibility()
+                self.zoom_scale.set_value(1.0)
+        else:
+            if self.get_expanded():
+                DepsManager(self.app)
+            self.set_expanded(False)
+
+    def _defaultValuesCb(self, widget):
+        self.disconnectSpinButtonsFromFlush()
+        for name, spinbtn in self.spin_buttons.items():
+            spinbtn.set_value(self.default_values[name])
+        self.app.gui.viewer.pipeline.flushSeekVideo()
+        self.connectSpinButtonsToFlush()
+        self.track_effect.gnl_object.props.active = False
+
+    def disconnectSpinButtonsFromFlush(self):
+        for spinbtn in self.spin_buttons.values():
+            spinbtn.disconnect_by_func(self._flushPipeLineCb)
+
+    def connectSpinButtonsToFlush(self):
+        for spinbtn in self.spin_buttons.values():
+            spinbtn.connect("output", self._flushPipeLineCb)
+
+    def _updateSpinButtons(self):
+        for name, spinbtn in self.spin_buttons.items():
+            spinbtn.set_value(self.effect.get_property(name))
+
+    def _getAndConnectToEffect(self, widget_name, property_name):
+        spinbtn = self.builder.get_object(widget_name)
+        spinbtn.connect("output",
+                        self._onValueChangedCb, property_name)
+        self.spin_buttons[property_name] = spinbtn
+        self.default_values[property_name] = spinbtn.get_value()
+
+    def _onValueChangedCb(self, spinbtn, prop):
+        value = spinbtn.get_value()
+
+        if value != self.default_values[prop] and not self.track_effect.gnl_object.props.active:
+            self.track_effect.gnl_object.props.active = True
+
+        if value != self.effect.get_property(prop):
+            self.action_log.begin("Transformation property change")
+            self.effect.set_property(prop, value)
+            self.action_log.commit()
+        box = self.app.gui.viewer.internal.box
+
+        # update box when values are changed in the spin boxes,
+        # so no point is selected
+        if box and box.clicked_point == 0:
+            box.update_from_effect(self.effect)
+
+    def _flushPipeLineCb(self, widget):
+        self.app.gui.viewer.pipeline.flushSeekVideo()
+
+    def _findEffect(self, name):
+        for track_effect in self._current_tl_obj.track_objects:
+            if isinstance(track_effect, TrackEffect):
+                if name in track_effect.getElement().get_path_string():
+                        self.track_effect = track_effect
+                        return track_effect.getElement()
+
+    def _findOrCreateEffect(self, name):
+        effect = self._findEffect(name)
+        if not effect:
+            factory = self.app.effects.getFactoryFromName(name)
+            self.timeline.addEffectFactoryOnObject(factory, [self._current_tl_obj])
+            effect = self._findEffect(name)
+            # disable the effect on default
+            self.track_effect.gnl_object.props.active = False
+        self.app.gui.viewer.internal.set_transformation_properties(self)
+        effect.freeze_notify()
+        return effect
+
+    def _selectionChangedCb(self, timeline):
+        if self.timeline and len(self.timeline.selection.selected) > 0:
+            for tl_obj in self.timeline.selection.selected:
+                pass
+
+            if tl_obj != self._current_tl_obj:
+                self._current_tl_obj = tl_obj
+                self.effect = None
+
+            self.set_sensitive(True)
+            if self.get_expanded():
+                self.effect = self._findOrCreateEffect("frei0r-filter-scale0tilt")
+                self._updateSpinButtons()
+        else:
+            if self._current_tl_obj:
+                self._current_tl_obj = None
+                self.zoom_scale.set_value(1.0)
+                self.app.gui.viewer.pipeline.flushSeekVideo()
+            self.effect = None
+            self.set_sensitive(False)
+        self._updateBoxVisibility()
+
+    def _updateBoxVisibility(self):
+        if self.get_expanded() and self._current_tl_obj:
+            self.app.gui.viewer.internal.show_box()
+        else:
+            self.app.gui.viewer.internal.hide_box()
+
+    def _getTimeline(self):
+        return self._timeline
+
+    def _setTimeline(self, timeline):
+        self._timeline = timeline
+        if timeline:
+            self.timeline.connect('selection-changed', self._selectionChangedCb)
+
+    timeline = property(_getTimeline, _setTimeline)
