@@ -32,6 +32,7 @@ from gettext import gettext as _
 from pitivi.log.loggable import Loggable
 from pitivi.configure import get_ui_dir
 import pitivi.ui.dynamic as dynamic
+from pitivi.ui.common import SPACING
 
 
 def make_property_widget(unused_element, prop, value=None):
@@ -109,28 +110,33 @@ class GstElementSettingsWidget(gtk.VBox, Loggable):
         else:
             table = gtk.Table(rows=len(props), columns=2)
 
-        table.set_row_spacings(5)
-        table.set_col_spacings(5)
-        table.set_border_width(5)
+        table.set_row_spacings(SPACING)
+        table.set_col_spacings(SPACING)
+        table.set_border_width(SPACING)
         y = 0
         for prop in props:
             if not prop.flags & gobject.PARAM_WRITABLE\
               or not prop.flags & gobject.PARAM_READABLE:
                 continue
 
-            label = gtk.Label(prop.nick + ":")
-            label.set_alignment(0.0, 0.5)
-            table.attach(label, 0, 1, y, y + 1, xoptions=gtk.FILL, yoptions=gtk.FILL)
             if use_element_props:
                 prop_value = self.element.get_property(prop.name)
             else:
                 prop_value = properties.get(prop.name)
+
             widget = make_property_widget(self.element, prop, prop_value)
+            if isinstance(widget, dynamic.ToggleWidget):
+                widget.set_label(prop.nick)
+                table.attach(widget, 0, 2, y, y + 1, yoptions=gtk.FILL)
+            else:
+                label = gtk.Label(prop.nick + ":")
+                label.set_alignment(0.0, 0.5)
+                table.attach(label, 0, 1, y, y + 1, xoptions=gtk.FILL, yoptions=gtk.FILL)
+                table.attach(widget, 1, 2, y, y + 1, yoptions=gtk.FILL)
 
             if hasattr(prop, 'description'):   # TODO: check that
                 widget.set_tooltip_text(prop.description)
 
-            table.attach(widget, 1, 2, y, y + 1, yoptions=gtk.FILL)
             self.properties[prop] = widget
             if default_btn:
                 button = self._getResetToDefaultValueButton(prop, widget)
@@ -151,8 +157,8 @@ class GstElementSettingsWidget(gtk.VBox, Loggable):
     def _getResetToDefaultValueButton(self, prop, widget):
         icon = gtk.Image()
         icon.set_from_stock('gtk-clear', gtk.ICON_SIZE_MENU)
-        button = gtk.Button(label='')
-        button.set_image(icon)
+        button = gtk.Button()
+        button.add(icon)
         button.set_tooltip_text(_("Reset to default value"))
         button.connect('clicked', self._defaultBtnClickedCb, widget)
         return button
@@ -187,6 +193,7 @@ class GstElementSettingsDialog(Loggable):
         self.builder.add_from_file(os.path.join(get_ui_dir(),
             "elementsettingsdialog.ui"))
         self.builder.connect_signals(self)
+        self.ok_btn = self.builder.get_object("okbutton1")
 
         self.window = self.builder.get_object("dialog1")
         self.elementsettings = GstElementSettingsWidget()
@@ -224,3 +231,10 @@ class GstElementSettingsDialog(Loggable):
     def getSettings(self):
         """ returns the property/value dictionnary of the selected settings """
         return self.elementsettings.getSettings()
+
+    def _resetValuesClickedCb(self, unused_button):
+        self.resetAll()
+
+    def resetAll(self):
+        for prop, widget in self.elementsettings.properties.iteritems():
+            widget.setWidgetToDefault()
