@@ -48,7 +48,7 @@ from pitivi.log.loggable import Loggable
 from pitivi.ui.timeline import Timeline
 from pitivi.ui.basetabs import BaseTabs
 from pitivi.ui.viewer import PitiviViewer
-from pitivi.configure import pitivi_version, APPNAME, APPURL, APPMANUALURL, \
+from pitivi.configure import pitivi_version, APPNAME, APPURL, \
      get_pixmap_dir, LIBDIR, get_ui_dir
 from pitivi.ui import dnd
 from pitivi.pipeline import Pipeline
@@ -62,8 +62,9 @@ from pitivi.ui.effectlist import EffectList
 from pitivi.ui.clipproperties import ClipProperties
 from pitivi.ui.common import SPACING
 from pitivi.ui.common import factory_name
-from pitivi.utils import beautify_length
+from pitivi.utils import beautify_length, show_user_manual
 from pitivi.ui.zoominterface import Zoomable
+from pitivi.ui.filechooserpreview import PreviewWidget
 
 if HAVE_GCONF:
     D_G_INTERFACE = "/desktop/gnome/interface"
@@ -150,6 +151,7 @@ def create_stock_icons():
             ('pitivi-ungroup', _('Ungroup'), 0, 0, 'pitivi'),
             # Translators: This is an action, the title of a button
             ('pitivi-group', _('Group'), 0, 0, 'pitivi'),
+            ('pitivi-align', _('Align'), 0, 0, 'pitivi'),
             ])
     pixmaps = {
         "pitivi-render": "pitivi-render-24.png",
@@ -159,6 +161,7 @@ def create_stock_icons():
         "pitivi-link": "pitivi-relink-24.svg",
         "pitivi-ungroup": "pitivi-ungroup-24.svg",
         "pitivi-group": "pitivi-group-24.svg",
+        "pitivi-align": "pitivi-align-24.svg",
     }
     factory = gtk.IconFactory()
     pmdir = get_pixmap_dir()
@@ -421,7 +424,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
         self.clipconfig = ClipProperties(instance, self.uimanager)
         self.clipconfig.project = self.project
         self.propertiestabs.append_page(self.clipconfig,
-                                        gtk.Label(_("Effects configurations")))
+                                        gtk.Label(_("Clip configuration")))
         self.clipconfig.show()
 
         self.secondhpaned.pack2(self.propertiestabs, resize=True, shrink=False)
@@ -565,6 +568,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
 
     def _newProjectMenuCb(self, unused_action):
         self.app.projectManager.newBlankProject()
+        self.app.gui.showProjectSettingsDialog()
 
     def _openProjectCb(self, unused_action):
         self.openProject()
@@ -590,7 +594,8 @@ class PitiviMainWindow(gtk.Window, Loggable):
 
     def showProjectSettingsDialog(self):
         from projectsettings import ProjectSettingsDialog
-        ProjectSettingsDialog(self, self.app.current).window.show()
+        ProjectSettingsDialog(self, self.app.current).window.run()
+        self.updateTitle()
 
     def _quitCb(self, unused_action):
         self._saveWindowSettings()
@@ -611,7 +616,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
             action.props.active
 
     def _userManualCb(self, unused_action):
-        webbrowser.open_new(APPMANUALURL)
+        show_user_manual()
 
     def _aboutResponseCb(self, dialog, unused_response):
         dialog.destroy()
@@ -843,19 +848,17 @@ class PitiviMainWindow(gtk.Window, Loggable):
     def _projectManagerRevertingToSavedCb(self, projectManager, project):
         if project.hasUnsavedModifications():
             dialog = gtk.MessageDialog(self,
-                                gtk.DIALOG_MODAL,
-                                gtk.MESSAGE_WARNING,
-                                gtk.BUTTONS_NONE,
-                                _("Do you want to reload current project?")
-                                )
+                    gtk.DIALOG_MODAL,
+                    gtk.MESSAGE_WARNING,
+                    gtk.BUTTONS_NONE,
+                    _("Do you want to reload current project?"))
             dialog.set_icon_name("pitivi")
             dialog.add_buttons(gtk.STOCK_CANCEL, gtk.RESPONSE_NO,
-                                        gtk.STOCK_REVERT_TO_SAVED, gtk.RESPONSE_YES)
+                    gtk.STOCK_REVERT_TO_SAVED, gtk.RESPONSE_YES)
             dialog.set_title(_("Revert to saved project"))
             dialog.set_resizable(False)
             dialog.set_property("secondary-text",
-                                            _("All unsaved changes will be lost.")
-                                        )
+                    _("All unsaved changes will be lost."))
             dialog.set_default_response(gtk.RESPONSE_NO)
             dialog.set_transient_for(self)
             response = dialog.run()
@@ -872,7 +875,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
             gtk.BUTTONS_OK,
             _('Unable to load project "%s"') % project_filename)
         dialog.set_icon_name("pitivi")
-        dialog.set_title(_("Error Loading File"))
+        dialog.set_title(_("Error Loading Project"))
         dialog.set_property("secondary-text", unquote(str(exception)))
         dialog.set_transient_for(self)
         dialog.run()
@@ -909,6 +912,10 @@ class PitiviMainWindow(gtk.Window, Loggable):
 
         chooser = gtk.FileChooserWidget(action=gtk.FILE_CHOOSER_ACTION_OPEN)
         chooser.set_select_multiple(False)
+        pw = PreviewWidget(self.app)
+        chooser.set_preview_widget(pw)
+        chooser.set_use_preview_label(False)
+        chooser.connect('update-preview', pw.add_preview_request)
         chooser.set_current_folder(self.settings.lastProjectFolder)
         dialog.get_content_area().pack_start(chooser, True, True)
         chooser.show()
@@ -970,14 +977,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
         redo_action = self.actiongroup.get_action("Redo")
         can_redo = bool(action_log.redo_stacks)
         redo_action.set_sensitive(can_redo)
-
-        if self.project is not None:
-            app_name = "%s" % (APPNAME)
-            title = u"%s \u2014 %s" % (self.project.name, app_name)
-            if dirty:
-                title = "*" + title
-            title = title.encode("utf8")
-            self.set_title(title)
+        self.updateTitle()
 
 ## PiTiVi current project callbacks
 
@@ -1142,3 +1142,15 @@ class PitiviMainWindow(gtk.Window, Loggable):
             self.project.pipeline.seek(position, format)
         except:
             self.debug("Seeking failed")
+
+    def updateTitle(self):
+        name = touched = ""
+        if self.project:
+            if self.project.name:
+                name = self.project.name
+            else:
+                name = _("Untitled project")
+            if self.project.hasUnsavedModifications():
+                touched = "*"
+        title = u"%s%s \u2014 %s" % (touched, name, APPNAME)
+        self.set_title(title)
