@@ -50,11 +50,31 @@ GlobalSettings.addConfigOption("thumbnailSpacingHint",
     default=2,
     notify=True)
 
+GlobalSettings.addConfigOption("thumbnailPeriod",
+    section="thumbnailing",
+    key="thumbnail-period",
+    default=gst.SECOND,
+    notify=True)
+
 PreferencesDialog.addNumericPreference("thumbnailSpacingHint",
     section=_("Appearance"),
-    label=_("Thumbnail Gap (pixels)"),
+    label=_("Thumbnail gap"),
     lower=0,
-    description=_("The gap between thumbnails"))
+    description=_("The spacing between thumbnails, in pixels"))
+
+PreferencesDialog.addChoicePreference("thumbnailPeriod",
+    section=_("Performance"),
+    label=_("Thumbnail every"),
+    choices=(
+        (_("%s second") % "1/100", gst.SECOND / 100),
+        (_("%s second") % "1/10", gst.SECOND / 10),
+        (_("%s second") % "1/4", gst.SECOND / 4),
+        (_("%s second") % "1/2", gst.SECOND / 2),
+        (_("%s second") % "1", gst.SECOND),
+        (_("%s seconds") % "5", 5 * gst.SECOND),
+        (_("%s seconds") % "10", 10 * gst.SECOND),
+        (_("minute"), 60 * gst.SECOND)),
+    description=_("The interval, in seconds, between thumbnails."))
 
 # this default works out to a maximum of ~ 1.78 MiB per factory, assuming:
 # 4:3 aspect ratio
@@ -79,9 +99,9 @@ GlobalSettings.addConfigOption('showThumbnails',
     notify=True)
 
 PreferencesDialog.addTogglePreference('showThumbnails',
-    section=_("Appearance"),
-    label=_("Show Thumbnails (Video)"),
-    description=_("Show Thumbnails on Video Clips"))
+    section=_("Performance"),
+    label=_("Enable video thumbnails"),
+    description=_("Show thumbnails on video clips"))
 
 GlobalSettings.addConfigOption('showWaveforms',
     section='user-interface',
@@ -90,9 +110,9 @@ GlobalSettings.addConfigOption('showWaveforms',
     notify=True)
 
 PreferencesDialog.addTogglePreference('showWaveforms',
-    section=_("Appearance"),
-    label=_("Show Waveforms (Audio)"),
-    description=_("Show Waveforms on Audio Clips"))
+    section=_("Performance"),
+    label=_("Enable audio waveforms"),
+    description=_("Show waveforms on audio clips"))
 
 # Previewer                      -- abstract base class with public interface for UI
 # |_DefaultPreviewer             -- draws a default thumbnail for UI
@@ -381,7 +401,7 @@ class RandomAccessVideoPreviewer(RandomAccessPreviewer):
 
     def _segment_for_time(self, time):
         # quantize thumbnail timestamps to maximum granularity
-        return time - (time % self.tstep)
+        return utils.quantize(time, self.tperiod)
 
     def _thumbnailCb(self, unused_thsink, pixbuf, timestamp):
         gobject.idle_add(self._finishThumbnail, pixbuf, timestamp)
@@ -396,12 +416,19 @@ class RandomAccessVideoPreviewer(RandomAccessPreviewer):
     def _connectSettings(self, settings):
         RandomAccessPreviewer._connectSettings(self, settings)
         settings.connect("showThumbnailsChanged", self._showThumbsChanged)
+        settings.connect("thumbnailPeriodChanged",
+            self._thumbnailPeriodChanged)
         self._view = settings.showThumbnails
+        self.tperiod = settings.thumbnailPeriod
 
     def _showThumbsChanged(self, settings):
         self._view = settings.showThumbnails
         self.emit("update", None)
 
+    def _thumbnailPeriodChanged(self, settings):
+        self.tperiod = settings.thumbnailPeriod
+        self.emit("update", None)
+
 
 class StillImagePreviewer(RandomAccessVideoPreviewer):
     def _thumbForTime(self, cr, time, x, y):
