@@ -43,6 +43,10 @@ from pitivi.utils import Seeker
 from pitivi.ui.filelisterrordialog import FileListErrorDialog
 from pitivi.ui.curve import Curve
 from pitivi.ui.common import SPACING
+from pitivi.ui.alignmentprogress import AlignmentProgressDialog
+from pitivi.ui.depsmanager import DepsManager
+from pitivi.timeline.align import AutoAligner
+from pitivi.check import soft_deps
 
 from pitivi.factories.operation import EffectFactory
 
@@ -64,6 +68,7 @@ UNLINK = _("Break links between clips")
 LINK = _("Link together arbitrary clips")
 UNGROUP = _("Ungroup clips")
 GROUP = _("Group clips")
+ALIGN = _("Align clips based on their soundtracks")
 SELECT_BEFORE = ("Select all sources before selected")
 SELECT_AFTER = ("Select all after selected")
 
@@ -87,6 +92,7 @@ ui = '''
                 <menuitem action="UnlinkObj" />
                 <menuitem action="GroupObj" />
                 <menuitem action="UngroupObj" />
+                <menuitem action="AlignObj" />
                 <separator />
                 <menuitem action="Prevframe" />
                 <menuitem action="Nextframe" />
@@ -104,6 +110,7 @@ ui = '''
             <toolitem action="LinkObj" />
             <toolitem action="GroupObj" />
             <toolitem action="UngroupObj" />
+            <toolitem action="AlignObj" />
         </placeholder>
     </toolbar>
     <accelerator action="DeleteObj" />
@@ -158,8 +165,9 @@ class InfoStub(gtk.HBox, Loggable):
         self.infolabel.set_alignment(0, 0.5)
 
         self.questionbutton = gtk.Button()
-        self.questionbutton.set_image(gtk.image_new_from_stock(gtk.STOCK_INFO,
-                                                               gtk.ICON_SIZE_SMALL_TOOLBAR))
+        self.infoicon = gtk.Image()
+        self.infoicon.set_from_stock(gtk.STOCK_INFO, gtk.ICON_SIZE_SMALL_TOOLBAR)
+        self.questionbutton.add(self.infoicon)
         self.questionbutton.connect("clicked", self._questionButtonClickedCb)
         self._questionshowing = False
 
@@ -236,12 +244,17 @@ class Timeline(gtk.Table, Loggable, Zoomable):
 
         # zooming slider's "zoom fit" button
         zoom_controls_hbox = gtk.HBox()
-        zoom_best_fit_button = gtk.Button(_("Zoom"))
-        zoom_best_fit_button.set_relief(gtk.RELIEF_NONE)
-        zoom_best_fit_button.set_tooltip_text(ZOOM_FIT)
-        zoom_best_fit_button.set_image(gtk.image_new_from_stock(gtk.STOCK_ZOOM_FIT, gtk.ICON_SIZE_BUTTON))
-        zoom_best_fit_button.connect("clicked", self._zoomFitCb)
-        zoom_controls_hbox.pack_start(zoom_best_fit_button)
+        zoom_fit_btn = gtk.Button()
+        zoom_fit_btn.set_relief(gtk.RELIEF_NONE)
+        zoom_fit_btn.set_tooltip_text(ZOOM_FIT)
+        zoom_fit_icon = gtk.Image()
+        zoom_fit_icon.set_from_stock(gtk.STOCK_ZOOM_FIT, gtk.ICON_SIZE_BUTTON)
+        zoom_fit_btn_hbox = gtk.HBox()
+        zoom_fit_btn_hbox.pack_start(zoom_fit_icon)
+        zoom_fit_btn_hbox.pack_start(gtk.Label(_("Zoom")))
+        zoom_fit_btn.add(zoom_fit_btn_hbox)
+        zoom_fit_btn.connect("clicked", self._zoomFitCb)
+        zoom_controls_hbox.pack_start(zoom_fit_btn)
         # zooming slider
         self._zoomAdjustment = gtk.Adjustment()
         self._zoomAdjustment.set_value(Zoomable.getCurrentZoomLevel())
@@ -326,6 +339,8 @@ class Timeline(gtk.Table, Loggable, Zoomable):
                 self.ungroupSelected),
             ("GroupObj", "pitivi-group", None, "<Control>G", GROUP,
                 self.groupSelected),
+            ("AlignObj", "pitivi-align", None, "<Shift><Control>A", ALIGN,
+                self.alignSelected),
         )
 
         self.playhead_actions = (
@@ -350,6 +365,7 @@ class Timeline(gtk.Table, Loggable, Zoomable):
         self.unlink_action = actiongroup.get_action("UnlinkObj")
         self.group_action = actiongroup.get_action("GroupObj")
         self.ungroup_action = actiongroup.get_action("UngroupObj")
+        self.align_action = actiongroup.get_action("AlignObj")
         self.delete_action = actiongroup.get_action("DeleteObj")
         self.split_action = actiongroup.get_action("Split")
         self.keyframe_action = actiongroup.get_action("Keyframe")
@@ -713,6 +729,7 @@ class Timeline(gtk.Table, Loggable, Zoomable):
         unlink = False
         group = False
         ungroup = False
+        align = False
         split = False
         keyframe = False
         if timeline.selection:
@@ -720,6 +737,7 @@ class Timeline(gtk.Table, Loggable, Zoomable):
             if len(timeline.selection) > 1:
                 link = True
                 group = True
+                align = AutoAligner.canAlign(timeline.selection)
 
             start = None
             duration = None
@@ -748,6 +766,7 @@ class Timeline(gtk.Table, Loggable, Zoomable):
         self.unlink_action.set_sensitive(unlink)
         self.group_action.set_sensitive(group)
         self.ungroup_action.set_sensitive(ungroup)
+        self.align_action.set_sensitive(align)
         self.split_action.set_sensitive(split)
         self.keyframe_action.set_sensitive(keyframe)
 
@@ -768,7 +787,9 @@ class Timeline(gtk.Table, Loggable, Zoomable):
     def deleteSelected(self, unused_action):
         if self.timeline:
             self.app.action_log.begin("delete clip")
+            self.timeline.disableUpdates()
             self.timeline.deleteSelection()
+            self.timeline.enableUpdates()
             self.app.action_log.commit()
 
     def unlinkSelected(self, unused_action):
@@ -789,6 +810,24 @@ class Timeline(gtk.Table, Loggable, Zoomable):
         if self.timeline:
             self.timeline.groupSelection()
 
+    def alignSelected(self, unused_action):
+        if "NumPy" in soft_deps:
+            DepsManager(self.app)
+
+        elif self.timeline:
+            progress_dialog = AlignmentProgressDialog(self.app)
+            progress_dialog.window.show()
+            self.app.action_log.begin("align")
+            self.timeline.disableUpdates()
+
+            def alignedCb():  # Called when alignment is complete
+                self.timeline.enableUpdates()
+                self.app.action_log.commit()
+                progress_dialog.window.destroy()
+
+            pmeter = self.timeline.alignSelection(alignedCb)
+            pmeter.addWatcher(progress_dialog.updatePosition)
+
     def split(self, action):
         self.app.action_log.begin("split")
         self.timeline.disableUpdates()
