@@ -7,14 +7,17 @@ from common import LAYER_HEIGHT_EXPANDED, LAYER_HEIGHT_COLLAPSED, LAYER_SPACING
 
 TRACK_CONTROL_WIDTH = 75
 
+
 def track_name(track):
     stream_type = type(track.stream)
     if stream_type == stream.AudioStream:
-        return _("<b>Audio:</b>")
+        track_name = _("Audio:")
     elif stream_type == stream.VideoStream:
-        return _("<b>Video:</b>")
+        track_name = _("Video:")
     elif stream_type == stream.TextStream:
-        return _("<b>Text:</b>")
+        track_name = _("Text:")
+    return "<b>%s</b>" % track_name
+
 
 class TrackControls(gtk.Label):
     __gtype_name__ = 'TrackControls'
@@ -38,6 +41,7 @@ class TrackControls(gtk.Label):
             max_priority) * (LAYER_HEIGHT_EXPANDED +
             LAYER_SPACING))
 
+
 class TimelineControls(gtk.VBox):
     def __init__(self):
         gtk.VBox.__init__(self)
