@@ -16,8 +16,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this program; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+# Boston, MA 02110-1301, USA.
 
 import gobject
 gobject.threads_init()
@@ -29,12 +29,15 @@ from pitivi.stream import AudioStream, VideoStream
 from common import TestCase, SignalMonitor, FakeSinkFactory, FakeEffectFactory
 from pitivi.factories.test import VideoTestSourceFactory
 
+
 class BogusAction(Action):
     pass
 
+
 class WeirdAction(Action):
     pass
 
+
 class TestPipeline(TestCase):
 
     def setUp(self):
@@ -139,6 +142,7 @@ class TestPipeline(TestCase):
         loop = gobject.MainLoop()
 
         bag = {"last_state": None}
+
         def state_changed_cb(pipeline, state, bag, loop):
             bag["last_state"] = state
             loop.quit()
@@ -300,10 +304,6 @@ class TestPipeline(TestCase):
 
         self.pipeline.releaseQueueForFactoryStream(factory, stream)
 
-        gst.debug("pouet2")
-        self.failUnlessRaises(PipelineError,
-                self.pipeline.releaseQueueForFactoryStream, factory, stream)
-
         # should always fail with a src bin
         factory2 = VideoTestSourceFactory()
         stream2 = VideoStream(gst.Caps('any'), 'src')
@@ -320,4 +320,3 @@ class TestPipeline(TestCase):
 
 if __name__ == "__main__":
     main()
-
